@@ -6,11 +6,11 @@ def add(params0, params1):
     return params0 + params1
 
 
-def square(param, add_param):
+def square_plus_constant(z, constant):
     # print(globals())
     # print(globals()["testValue"])
     # print(testValue)
-    return np.square(param) + add_param
+    return np.square(z) + constant
 
 
 def double(param, add1, add2):
